..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


BayesPy -- Bayesian Python
==========================


.. toctree::
   :maxdepth: 2
   
   intro
   user_guide/user_guide
   examples/examples
   dev_guide/dev_guide
   user_api/user_api
   dev_api/dev_api
   references

* :doc:`Bibliography <references>`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

